﻿using System;
using System.Text;
using System.Threading;
using Microsoft.SPOT.Hardware;
using System.IO.Ports;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

using Microtoolskit.Hardware.Sensors;
using Microtoolskit.Hardware.Displays;

namespace Incubateur
{

    public class Program
    {
        enum Etat : ushort
        {
            chaufferOn = 0,
            chaufferOff = 1
        }

        public static void Main()
        {
            // Variables
            var temperature = 0.0; // <- A compléter
            var Tconsigne = 26.0;
            var ecart = 0.1;
            var ecartAlarme = 2.0;
            Etat etat = 0;
            byte[] outBuffer;

            // Création des objets virtuels  
            SerialPort uart = new SerialPort(SerialPorts.COM1, 115200);
            var ModuleMesureTemp = new TMP102();    // <- Objet ModuleMesureTemp à créer
            var CdeChauffage = new OutputPort(Pins.GPIO_PIN_D6, false);
            var Alarme = new PWM(PWMChannels.PWM_PIN_D11, 2000, 0.5, false);
            var Lcd = new ELCD162();

            // Initialisations
            ModuleMesureTemp.Init();
            CdeChauffage.Write(false);
            Lcd.Init(); // COM2
            Lcd.ClearScreen(); Lcd.CursorOff();
            Alarme.Stop();
            uart.Open();

            while (true)
            {
                // Lire la température
                temperature = ModuleMesureTemp.ReadAsCelcius(); // <- A compléter

                // Transmission
                string tempUart = temperature.ToString("F2") + ";" + "\r";
                outBuffer = Encoding.UTF8.GetBytes(tempUart);
                uart.Write(outBuffer, 0, outBuffer.Length);

                // Traitement
                // Alarme
                if ((temperature > (Tconsigne + ecartAlarme)) || (temperature < (Tconsigne - ecartAlarme)))
                {
                    //Alarme.Start();
                }
                else
                {
                    Alarme.Stop();
                }

                // Chauffage
                switch (etat)
                {
                    case Etat.chaufferOn:
                        CdeChauffage.Write(true);
                        if (temperature >= (Tconsigne + ecart))
                        {
                            etat = Etat.chaufferOff;
                        }
                        break;
                    case Etat.chaufferOff:
                        CdeChauffage.Write(false);
                        if (temperature <= (Tconsigne - ecart))
                        {
                            etat = Etat.chaufferOn;
                        }
                        break;
                    default:
                        break;
                }

                // Effacer le lcd
                Lcd.ClearScreen(); // <- A compléter


                // Afficher la température sur le lcd
                Lcd.PutString("Csg = " + Tconsigne.ToString("F1") + "C");
                Lcd.SetCursor(0, 1);
                Lcd.PutString("T = " + temperature.ToString("F2") + "C"); // <- A compléter

                Thread.Sleep(30000); // Attendre une seconde entre chaque mesure
            }
        }
    }
}
